Lookup
======
.. autodata:: pykeen.models.model_resolver
.. autodata:: pykeen.losses.loss_resolver
.. autodata:: pykeen.optimizers.optimizer_resolver
.. autodata:: pykeen.regularizers.regularizer_resolver
.. autodata:: pykeen.stoppers.stopper_resolver
.. autodata:: pykeen.sampling.negative_sampler_resolver
.. autodata:: pykeen.datasets.dataset_resolver
.. autodata:: pykeen.training.training_loop_resolver
.. autodata:: pykeen.evaluation.evaluator_resolver
.. autodata:: pykeen.evaluation.metric_resolver
.. autodata:: pykeen.hpo.pruners.pruner_resolver
.. autodata:: pykeen.hpo.samplers.sampler_resolver
